==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/CreateRateBasedRuleResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.waf.model.primitives.ChangeToken
import scala.jdk.CollectionConverters._
final case class CreateRateBasedRuleResponse(
    rule: Option[zio.aws.waf.model.RateBasedRule] = None,
    changeToken: Option[ChangeToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse = {
    import CreateRateBasedRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
      .builder()
      .optionallyWith(rule.map(value => value.buildAwsValue()))(_.rule)
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.CreateRateBasedRuleResponse.ReadOnly =
    zio.aws.waf.model.CreateRateBasedRuleResponse.wrap(buildAwsValue())
}
object CreateRateBasedRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.CreateRateBasedRuleResponse =
      zio.aws.waf.model.CreateRateBasedRuleResponse(
        rule.map(value => value.asEditable),
        changeToken.map(value => value)
      )
    def rule: Option[zio.aws.waf.model.RateBasedRule.ReadOnly]
    def changeToken: Option[ChangeToken]
    def getRule: ZIO[Any, AwsError, zio.aws.waf.model.RateBasedRule.ReadOnly] =
      AwsError.unwrapOptionField("rule", rule)
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
  ) extends zio.aws.waf.model.CreateRateBasedRuleResponse.ReadOnly {
    override val rule: Option[zio.aws.waf.model.RateBasedRule.ReadOnly] = scala
      .Option(impl.rule())
      .map(value => zio.aws.waf.model.RateBasedRule.wrap(value))
    override val changeToken: Option[ChangeToken] = scala
      .Option(impl.changeToken())
      .map(value => zio.aws.waf.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
  ): zio.aws.waf.model.CreateRateBasedRuleResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/CreateRateBasedRuleResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.waf.model.primitives.ChangeToken
import scala.jdk.CollectionConverters._
final case class CreateRateBasedRuleResponse(
    rule: Optional[zio.aws.waf.model.RateBasedRule] = Optional.Absent,
    changeToken: Optional[ChangeToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse = {
    import CreateRateBasedRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
      .builder()
      .optionallyWith(rule.map(value => value.buildAwsValue()))(_.rule)
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.CreateRateBasedRuleResponse.ReadOnly =
    zio.aws.waf.model.CreateRateBasedRuleResponse.wrap(buildAwsValue())
}
object CreateRateBasedRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.CreateRateBasedRuleResponse =
      zio.aws.waf.model.CreateRateBasedRuleResponse(
        rule.map(value => value.asEditable),
        changeToken.map(value => value)
      )
    def rule: Optional[zio.aws.waf.model.RateBasedRule.ReadOnly]
    def changeToken: Optional[ChangeToken]
    def getRule: ZIO[Any, AwsError, zio.aws.waf.model.RateBasedRule.ReadOnly] =
      AwsError.unwrapOptionField("rule", rule)
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
  ) extends zio.aws.waf.model.CreateRateBasedRuleResponse.ReadOnly {
    override val rule: Optional[zio.aws.waf.model.RateBasedRule.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.rule())
        .map(value => zio.aws.waf.model.RateBasedRule.wrap(value))
    override val changeToken: Optional[ChangeToken] = zio.aws.core.internal
      .optionalFromNullable(impl.changeToken())
      .map(value => zio.aws.waf.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.CreateRateBasedRuleResponse
  ): zio.aws.waf.model.CreateRateBasedRuleResponse.ReadOnly = new Wrapper(impl)
}
